@@ -36,6 +36,7 @@ from ironic.api.controllers.v1 import node
 from ironic.api.controllers.v1 import port
 from ironic.api.controllers.v1 import portgroup
 from ironic.api.controllers.v1 import ramdisk
+from ironic.api.controllers.v1 import runbook
 from ironic.api.controllers.v1 import shard
 from ironic.api.controllers.v1 import utils
 from ironic.api.controllers.v1 import versions
@@ -77,6 +78,7 @@ VERSIONED_CONTROLLERS = {
     'events': utils.allow_expose_events,
     'deploy_templates': utils.allow_deploy_templates,
     'shards': utils.allow_shards_endpoint,
+    'runbooks': utils.allow_runbooks,
     # NOTE(dtantsur): continue_inspection is available in 1.1 as a
     # compatibility hack to make it usable with IPA without changes.
     # Hide this fact from consumers since it was not actually available
@@ -131,6 +133,7 @@ class Controller(object):
         'deploy_templates': deploy_template.DeployTemplatesController(),
         'shards': shard.ShardController(),
         'continue_inspection': ramdisk.ContinueInspectionController(),
+        'runbooks': runbook.RunbooksController()
     }
 
     @method.expose()
@@ -138,8 +141,7 @@ class Controller(object):
         # NOTE: The reason why v1() it's being called for every
         #       request is because we need to get the host url from
         #       the request object to make the links.
-        self._add_version_attributes()
-        if api.request.method != "GET":
+        if api.request.method not in ('GET', 'HEAD'):
             pecan.abort(http_client.METHOD_NOT_ALLOWED)
 
         return v1()
@@ -166,7 +168,7 @@ class Controller(object):
                  'max': versions.max_version_string()},
                 headers=headers)
 
-    def _add_version_attributes(self):
+    def add_version_attributes(self):
         v = base.Version(api.request.headers, versions.min_version_string(),
                          versions.max_version_string())
 
@@ -183,7 +185,6 @@ class Controller(object):
 
     @pecan.expose()
     def _lookup(self, primary_key, *remainder):
-        self._add_version_attributes()
 
         controller = self._subcontroller_map.get(primary_key)
         if not controller:
