@@ -128,6 +128,9 @@ BASE_VERSION = 1
 # v1.88: Add name field to port.
 # v1.89: Add API for attaching/detaching virtual media
 # v1.90: Accept ovn vtep switch metadata schema to port.local_link_connection
+# v1.91: Remove special treatment of .json for API objects
+# v1.92: Add runbooks API
+# v1.93: Add GET API for virtual media
 
 MINOR_0_JUNO = 0
 MINOR_1_INITIAL_VERSION = 1
@@ -220,6 +223,9 @@ MINOR_87_SERVICE = 87
 MINOR_88_PORT_NAME = 88
 MINOR_89_ATTACH_DETACH_VMEDIA = 89
 MINOR_90_OVN_VTEP = 90
+MINOR_91_DOT_JSON = 91
+MINOR_92_RUNBOOKS = 92
+MINOR_93_GET_VMEDIA = 93
 
 # When adding another version, update:
 # - MINOR_MAX_VERSION
@@ -227,7 +233,7 @@ MINOR_90_OVN_VTEP = 90
 #   explanation of what changed in the new version
 # - common/release_mappings.py, RELEASE_MAPPING['master']['api']
 
-MINOR_MAX_VERSION = MINOR_90_OVN_VTEP
+MINOR_MAX_VERSION = MINOR_93_GET_VMEDIA
 
 # String representations of the minor and maximum versions
 _MIN_VERSION_STRING = '{}.{}'.format(BASE_VERSION, MINOR_1_INITIAL_VERSION)
