@@ -20,6 +20,7 @@ from oslo_config import types
 
 from ironic.common import boot_modes
 from ironic.common.i18n import _
+from ironic.common import lessee_sources
 
 
 opts = [
@@ -258,8 +259,7 @@ opts = [
                help=_('Password hash algorithm to be used for the rescue '
                       'password.')),
     cfg.BoolOpt('require_rescue_password_hashed',
-                # TODO(TheJulia): Change this to True in Victoria.
-                default=False,
+                default=True,
                 mutable=True,
                 help=_('Option to cause the conductor to not fallback to '
                        'an un-hashed version of the rescue password, '
@@ -346,15 +346,36 @@ opts = [
                         'for multiple steps. If set to 0, this specific step '
                         'will not run during verification. ')),
     cfg.BoolOpt('automatic_lessee',
-                default=False,
+                default=True,
                 mutable=True,
-                help=_('If the conductor should record the Project ID '
-                       'indicated by Keystone for a requested deployment. '
-                       'Allows rights to be granted to directly access the '
-                       'deployed node as a lessee within the RBAC security '
-                       'model. The conductor does *not* record this value '
-                       'otherwise, and this information is not backfilled '
-                       'for prior instances which have been deployed.')),
+                help=_('Deprecated. If Ironic should set the node.lessee '
+                       'field at deployment. Use '
+                       '[\'conductor\']/automatic_lessee_source instead.'),
+                deprecated_for_removal=True),
+    cfg.StrOpt('automatic_lessee_source',
+               help=_('Source for Project ID the Ironic should '
+                      'record at deployment time in node.lessee field. If set '
+                      'to none, Ironic will not set a lessee field. '
+                      'If set to instance (default), uses Project ID '
+                      'indicated in instance metadata set by Nova or '
+                      'another external deployment service. '
+                      'If set to keystone, Ironic uses Project ID indicated '
+                      'by Keystone context. '),
+               choices=[
+                   (lessee_sources.INSTANCE, _(  # 'instance'
+                    'Populates node.lessee field using metadata from '
+                    'node.instance_info[\'project_id\'] at deployment '
+                    'time. Useful for Nova-fronted deployments.')),
+                   (lessee_sources.REQUEST, _(  # 'request'
+                    'Populates node.lessee field using metadata '
+                    'from request context. Only useful for direct '
+                    'deployment requests to Ironic; not those proxied '
+                    'via an external service like Nova.')),
+                   (lessee_sources.NONE, _(  # 'none'
+                    'Ironic will not populate the node.lessee field.'))
+               ],
+               default='instance',
+               mutable=True),
     cfg.IntOpt('max_concurrent_deploy',
                default=250,
                min=1,
@@ -429,6 +450,49 @@ opts = [
                 mutable=True,
                 help=_("Specifies a list of boot modes that are not allowed "
                        "during deployment. Eg: ['bios']")),
+    cfg.BoolOpt('disable_deep_image_inspection',
+                default=False,
+                # Normally such an option would be mutable, but this is,
+                # a security guard and operators should not expect to change
+                # this option under normal circumstances.
+                mutable=False,
+                help=_('Security Option to permit an operator to disable '
+                       'file content inspections. Under normal conditions, '
+                       'the conductor will inspect requested image contents '
+                       'which are transferred through the conductor. '
+                       'Disabling this option is not advisable and opens '
+                       'the risk of unsafe images being processed which may '
+                       'allow an attacker to leverage unsafe features in '
+                       'various disk image formats to perform a variety of '
+                       'unsafe and potentially compromising actions. '
+                       'This option is *not* mutable, and '
+                       'requires a service restart to change.')),
+    cfg.BoolOpt('conductor_always_validates_images',
+                default=False,
+                # Normally mutable, however from a security context we do want
+                # all logging to be generated from this option to be changed,
+                # and as such is set to False to force a conductor restart.
+                mutable=False,
+                help=_('Security Option to enable the conductor to *always* '
+                       'inspect the image content of any requested deploy, '
+                       'even if the deployment would have normally bypassed '
+                       'the conductor\'s cache. When this is set to False, '
+                       'the Ironic-Python-Agent is responsible '
+                       'for any necessary image checks. Setting this to '
+                       'True will result in a higher utilization of '
+                       'resources (disk space, network traffic) '
+                       'as the conductor will evaluate *all* images. '
+                       'This option is *not* mutable, and requires a '
+                       'service restart to change. This option requires '
+                       '[conductor]disable_deep_image_inspection to be set '
+                       'to False.')),
+    cfg.ListOpt('permitted_image_formats',
+                default=['raw', 'qcow2', 'iso'],
+                mutable=True,
+                help=_('The supported list of image formats which are '
+                       'permitted for deployment with Ironic. If an image '
+                       'format outside of this list is detected, the image '
+                       'validation logic will fail the deployment process.')),
 ]
 
 
