@@ -237,7 +237,7 @@ class PXEBaseMixin(object):
         Basic challenge: IPMI doesn't have a field reserved for "httpboot" as
         httpboot pre-dates IPMI. It is also entirely possible that all logic
         to support httpboot is coming from OPROM code on network cards, so to
-        sort of handle this, and the nature of PXE being percieved as
+        sort of handle this, and the nature of PXE being perceived as
         "network boot", if we are http boot enabled, we attempt to explicitly
         request as such, but if the driver errors, then we fall back to PXE.
 
@@ -441,10 +441,11 @@ class PXEBaseMixin(object):
         """
         try:
             self._validate_common(task)
-        except exception.MissingParameterValue:
+        except exception.MissingParameterValue as exc:
             # Fall back to non-managed in-band inspection
             raise exception.UnsupportedDriverExtension(
-                driver=task.node.driver, extension='inspection')
+                _("Insufficient information provided for managed "
+                  "inspection: %s") % exc)
 
     _RETRY_ALLOWED_STATES = {states.DEPLOYWAIT, states.CLEANWAIT,
                              states.RESCUEWAIT}
