@@ -646,6 +646,19 @@ class TestNeutronNetworkActions(db_base.DbTestCase):
 
         self.assertEqual(expected_network, network_data['networks'][0])
 
+        expected_services = [
+            {
+                'type': 'dns',
+                'address': '192.0.2.253'
+            },
+            {
+                'type': 'dns',
+                'address': '192.0.2.254'
+            }
+        ]
+
+        self.assertEqual(expected_services, network_data['services'])
+
     def load_ipv6_files(self):
         port_show_file = os.path.join(
             os.path.dirname(__file__), 'json_samples',
@@ -705,6 +718,13 @@ class TestNeutronNetworkActions(db_base.DbTestCase):
 
         self.assertEqual(expected_network, network_data['networks'][0])
 
+        expected_service = {
+            'type': 'dns',
+            'address': '2001:db8::ffff:c000:2fe'
+        }
+
+        self.assertEqual(expected_service, network_data['services'][0])
+
     def test_get_node_portmap(self):
         with task_manager.acquire(self.context, self.node.uuid) as task:
             portmap = neutron.get_node_portmap(task)
@@ -1431,7 +1451,7 @@ class TestNeutronNetworkInterfaceMixin(db_base.DbTestCase):
         self.node = object_utils.create_test_node(self.context)
 
     def test_get_network_names_and_uuids(self):
-        """A test to validate confiured overrides work."""
+        """A test to validate configured overrides work."""
         for name in ['cleaning', 'provisioning', 'rescuing', 'inspection',
                      'servicing']:
             method_name = 'get_{}_network_uuid'.format(name)
